unit Demo5Settings;
//  If you are using Delphi 6 Enterprise then disable this compiler directive :
{$DEFINE MyXML}

interface

uses
{$IFDEF MyXML}
  PtSettingsMyXML,
{$ELSE}
  PtSettingsXML,
{$ENDIF}
  PtSettings, Graphics;

type
  TSettings = class(TSettingsGroup)
  private
    fColour: TColor;
    fText: String;
  published
    property  Colour  : TColor  read fColour  write fColour;
    property  Text    : String  read fText    write fText;
  end;

  TStorageProxy = class(TInterfacedObject, ISettingsStorage)
  private
    fStore: TXMLSettingsStorage;
    function GetIsConnected: Boolean;
  protected
    property  Store : TXMLSettingsStorage read fStore;
    procedure Fetch;
    procedure Send;
  public
    constructor Create;
    destructor  Destroy; override;
    property  IsConnected : Boolean read GetIsConnected;
    procedure Load(const Group: TSettingsGroup);
    procedure Save(const Group: TSettingsGroup);
    procedure LoadAll(const Group: TSettingsGroup);
    procedure SaveAll(const Group: TSettingsGroup);
    procedure DeleteAll(const Group: TSettingsGroup);
  end;

var
  Settings: TSettings;
  Storage: ISettingsStorage;

procedure Initialize;
procedure Finalize;

implementation

uses
{$IFDEF MyXML}
  MyXML, 
{$ELSE}
  XMLDoc,
{$ENDIF}
  FMain, SysUtils, Forms;

procedure Initialize;
begin
  Settings := TSettings.Create('Demo5', nil);
  Storage := TStorageProxy.Create;
end;

procedure Finalize;
begin
  Storage.SaveAll( Settings );
  Settings.Free;
end;

function  FileName(const FileName: string): string;
begin
  Result  := ExtractFilePath(Application.ExeName)+FileName+'.xml'
end;

{ TStorageProxy }

constructor TStorageProxy.Create;
begin
  inherited;
  fStore  := TXMLSettingsStorage.Create( NewXMLDocument );
end;

procedure TStorageProxy.DeleteAll(const Group: TSettingsGroup);
begin
  Store.DeleteAll( Group );
end;

destructor TStorageProxy.Destroy;
begin
  fStore.Free;
  inherited;
end;

procedure TStorageProxy.Fetch;
begin
  if  IsConnected then
    //  In this application we cheat, and simply load the settings from file.
    begin
      if  FileExists( FileName('Server') )  then
        Store.XMLDocument.LoadFromFile( FileName('Server') )
    end
  else
    //  Not connected, so load default settings that are stored locally.
    begin
      if  FileExists( FileName('Client') )  then
        Store.XMLDocument.LoadFromFile( FileName('Client') );
    end
end;

function TStorageProxy.GetIsConnected: Boolean;
begin
  //  Super cheat.  
  Result  := frmMain.chkConnect.Checked
end;

procedure TStorageProxy.Load(const Group: TSettingsGroup);
begin
  Fetch;
  Store.Load( Group );
end;

procedure TStorageProxy.LoadAll(const Group: TSettingsGroup);
begin
  Fetch;
  Store.LoadAll( Group );
end;

procedure TStorageProxy.Save(const Group: TSettingsGroup);
begin
  Store.Save( Group );
  Send;
end;

procedure TStorageProxy.SaveAll(const Group: TSettingsGroup);
begin
  Store.SaveAll( Group );
  Send;
end;

procedure TStorageProxy.Send;
begin
  if  IsConnected then
    //  In this application we cheat, and simply save the settings to file.
    Store.XMLDocument.SaveToFile( FileName('Server') )
  else
    //  Not connected, so save default settings locally.
    Store.XMLDocument.SaveToFile( FileName('Client') );
end;

end.
 
