unit PtSettingsMyXML;
//  Versions:     Delphi 6
//  Created by:   Peter Thnell
//  Contact:      thonellp@hotmail.com
//  When:         2002-08

//  ISettingsStorage implementation for XML, using interfaces declared in XMLIntf.

interface

uses
  PtSettings, Classes, MyXML;

type
  TXMLSettingsStorage = class(TSettingsStorage, ISettingsStorageRead,
    ISettingsStorageWrite, ISettingsStorageDelete, ISettingsStorageQuery)
  protected
    //  IReadSettingsStorage
    function  ReadValue(const Name: string): OleVariant;
    function  ReadInt(const Name: string): integer; override;
    function  ReadString(const Name: string): string; override;
    function  ReadWideString(const Name: string): WideString; override;
    function  ReadFloat(const Name: string): double; override;
    function  ReadInt64(const Name: string): Int64; override;
    //  IWriteSettingsStorage
    procedure WriteInt(const Name: string; const Value: integer); override;
    procedure WriteString(const Name: string; const Value: string); override;
    procedure WriteWideString(const Name: string; const Value: WideString); override;
    procedure WriteFloat(const Name: string; const Value: double); override;
    procedure WriteInt64(const Name: string; const Value: Int64); override;
    //  IDeleteSettingsStorage
    procedure DeleteSetting(const Name: string); override;
    //  IQuerySettingsStorage
    procedure GetSettingNames(const SettingNames: TStrings); override;
    procedure GetGroupNames(const GroupNames: TStrings); override;
    //  Tools
    function  FindXMLNode(const Group: TSettingsGroup; const CanCreate: Boolean): IMyXMLNode;
  public
    constructor Create(const AXMLDocument: IMyXMLDocument; const AFileName: string = '');
    procedure Load(const Group: TSettingsGroup); override;
    procedure Save(const Group: TSettingsGroup); override;
    procedure LoadAll(const Group: TSettingsGroup); override;
    procedure SaveAll(const Group: TSettingsGroup); override;
    procedure DeleteAll(const Group: TSettingsGroup); override;
    property  XMLDocument : IMyXMLDocument  read fXMLDocument write fXMLDocument;
    property  FileName    : string        read fFileName    write fFileName;
  end;

implementation

end.
